function [A,b] = HeatedPlateMesh(n,T)
%-----------------------------------------------------------------
% This code creates the [A] and b for a heated plate with fixed
% temperatures along all sides. The plates is discretized with a
% uniform grid of n x n nodes with equal spacing in the x and y
% directions. Note, there are n^2 nodes in a n x n grid.  The heat
% conduction equation is used to determine the temperature at the
% (i,j) node.
%
% INPUT
%   n     size of grid
%   T     vector of temperatures along four sides, T=[TN,TW,TE,TS]
%
% OUPUT
%   A     system matrix (n^2 x n^2)
%   b     right hand side vector (n^2 x 1)
%
%-----------------------------------------------------------------

% temperatures along the four faces (degrees F)
TN=T(1);
TW=T(2);
TE=T(3);
TS=T(4);

% initialize [A] and b to zero
A = zeros(n^2,n^2);
b = zeros(n^2,1);

% loop (S-N rows of grid)
for (i=1:n)
  % loop (W-E columns of grid)
  for (j=1:n)
    % node number --- starting from SW corner (i=1,j=1) and moving
    % horizontal to the east side (i=1,j-n), then up one row and
    % starting from the west side (i=2,j=1) and moving horizontal,
    % and so on
    k=(i-1)*n+j;
    
    % all diagonal elements are the same
    A(k,k)=4;
    
    % take care of south side
    if (i==1)
      % SW corner
      if (j==1)
        A(k,k+1)=-1;A(k,k+n)=-1;b(k)=TS+TW;
      % SE corner
      elseif (j==n)
        A(k,k-1)=-1;A(k,k+n)=-1;b(k)=TS+TE;
      % S edge
      else
        A(k,k+1)=-1;A(k,k-1)=-1;A(k,k+n)=-1;b(k)=TS;
      end
      
    % take care of north side
    elseif (i==n)
      % NW corner
      if (j==1)
        A(k,k+1)=-1;A(k,k-n)=-1;b(k)=TN+TW;
      % NE corner
      elseif (j==n)
        A(k,k-1)=-1;A(k,k-n)=-1;b(k)=TN+TE;
      % N edge
      else
        A(k,k+1)=-1;A(k,k-1)=-1;A(k,k-n)=-1;b(k)=TN;
      end
      
    else
      % W side
      if (j==1)
        A(k,k+1)=-1;A(k,k-n)=-1;A(k,k+n)=-1;b(k)=TW;
      % E side
      elseif (j==n)
        A(k,k-1)=-1;A(k,k-n)=-1;A(k,k+n)=-1;b(k)=TE;
      % all interior nodes
      else
        A(k,k+1)=-1;A(k,k-1)=-1;A(k,k-n)=-1;A(k,k+n)=-1;
      end
    end
  end
end

      
        