function Tmat = TempMatrix(x,T,n)
%-----------------------------------------------------------------
% This code creates a matrix containing the temperatures at
% each (i,j) node in the grid using the solution vector, x. The output can then be used to plot
% a contour plot of the temperature distribution along the plate.
%
% The solution vector is expected to be ordered as follows: the
% first element corresponds to the SW corner (i=1,j=1), the nth
% element corresponds to the SE corner (i=1,j=n), the n*(n-1)+1
% element corresponds to the NW corner (i=n,j=1), and the n^2
% element corresponds to the NE corner (i=n,j=n).
%
% x(1) = T_{1,1}
% x(2) = T_{1,2}
% ...
% x(n-1) = T_{1,n-1}
% x(n) = T_{1,n}
% x(n+1) = T_{2,1}
% x(n+2) = T_{2,2}
% ...
% x(2n-1) = T_{2,n-1}
% x(2n) = T_{2,n}
% ...
% x(n*(n-1)+1) = T_{n,1}
% x(n*(n-1)+2) = T_{n,2}
% ...
% x(n^2-1) = T_{n,n-1}
% x(n^2) = T_{n,n} 
%
% This code adds temperatures along the four sides and NaNs in each
% corner, since the temperature at the corners are not defined. The
% final size of T is (n+2 x n+2)
%
% INPUT
%   x     solution vector from the heated plate problem
%   T     vector of temperatures along four sides, T=[TN,TW,TE,TS]
%   n     size of grid
%
% OUPUT
%   Tmat  (n+2 x n+2) matrix containing temperatures at each 
%         i,j node as well as the side walls
%
%-----------------------------------------------------------------

% initialize output
Tmat = zeros(n,n);

% temperatures along the four faces (degrees F)
TN=T(1);
TW=T(2);
TE=T(3);
TS=T(4);

% loop (S-N rows of grid)
for (i=1:n)
  % loop (W-E column of grid)
  for (j=1:n)
    % node number - index of x
    k = (i-1)*n+j;
    
    Tmat(i,j)=x(k);
  end
end

% add temperatures along South side wall (i=1)
TSwall=TS*ones(1,n);
Tmat = [TSwall;Tmat];

% add temperatures along North side wall (i=n)
TNwall=TN*ones(1,n);
Tmat = [Tmat;TNwall];

% add temperatures along West side wall (j=1)
TWwall=[NaN;TW*ones(n,1);NaN];
Tmat = [TWwall';Tmat']';

% add temperatures along East side wall (j=n)
TEwall=[NaN;TE*ones(n,1);NaN];
Tmat = [Tmat';TEwall']';


